//	Circular SineWave script, 2/23/2012.
//	Foremerly WaveSpring script of 11/21/2012
//	by Brian E. McMillin

function alert( msg )
{
	moi.ui.commandUI.alert( msg );
}

function Update()
{
	var factory = moi.command.createFactory( 'curve' );
 	var radius = moi.ui.commandUI.radius.numericValue;
	var numwaves = moi.ui.commandUI.numwaves.integerValue;
	var amplitude = moi.ui.commandUI.amplitude.numericValue;
	var numpoints = moi.ui.commandUI.numpoints.integerValue * numwaves;
	var buildtype = moi.ui.commandUI.Build.value;
	
	for ( var i = 0; i < numpoints; ++i )

	{
		var t = i / (numpoints - 1);

		// theta is the rotational angle parameter, (0 to 2pi) , to generate 360 degree profile.
		var theta;
		theta = Math.PI * 2.0 * t;
		// Define x, y and z values.  
  
		if (buildtype == 'flat')
		{
			var x = (radius + amplitude * Math.sin( numwaves * theta )) * Math.cos(theta);
			var y = (radius + amplitude * Math.sin( numwaves * theta )) * Math.sin(theta)
			var z = 0;
			var pt = moi.vectorMath.createPoint( x, y, z );
			factory.createInput( 'point' );
			factory.setInput( factory.numInputs - 1, pt );
		}		
		else if (buildtype == 'cylindrical')
		{
			var x = radius * Math.cos( theta );
			var y = radius * Math.sin( theta );
			var z = amplitude * Math.sin(numwaves * theta );
			var pt = moi.vectorMath.createPoint( x, y, z );			
			factory.createInput( 'point' );
			factory.setInput( factory.numInputs - 1, pt );
		}
		else  // spherical
		{
			var r2 = radius * radius;
			var ampl2 = amplitude * amplitude;
			if (r2 < ampl2)
			{
				alert ( "Amplitude is too extreme versus radius" );
				break; // imaginary numbers not allowed.
			}			
			var cos2_n_theta = Math.cos( numwaves * theta ) * Math.cos( numwaves * theta );
			var sqrt_val = Math.sqrt(r2 - ampl2 * cos2_n_theta );
			var x = Math.cos( theta ) * sqrt_val;
			var y = Math.sin( theta ) * sqrt_val;
			var z = amplitude * Math.cos( numwaves * theta );
			var pt = moi.vectorMath.createPoint( x, y, z );			
			factory.createInput( 'point' );
			factory.setInput( factory.numInputs - 1, pt );
		}
	}
	
	factory.update();
	
	return factory;
}

function DoCircularSineWave()
{
	var factory = Update();

	var dlg = moi.ui.commandDialog;
	
	while ( 1 )
	{
		if ( !dlg.waitForEvent() )
		{
			factory.cancel();
			return false;
		}
			
		if ( dlg.event == 'done' )
			break;
			
		if ( dlg.event == 'radius' || dlg.event == 'numwaves' || dlg.event == 'amplitude' || dlg.event == 'numpoints' || dlg.event == 'Build' )
		{
			factory.cancel();
			factory = Update();
		}
	}
	
	factory.commit();
}

DoCircularSineWave();
